==> custom-split-chunk-webpack-plugin-0.0.1-dev.0.tgz: package/library/index.js <==
const PLUGIN_NAME = "CustomSplitChunkWebpackPlugin";
exports.CustomSplitChunkWebpackPlugin = class {
  constructor(customOptionList) {
    this.customOptionList = verifyCustomOptionList(customOptionList);
  }
  apply(compiler) {
    compiler.hooks.thisCompilation.tap(PLUGIN_NAME, compilation => {
      let alreadyOptimized = !1;
      compilation.hooks.unseal.tap(PLUGIN_NAME, () => {
        alreadyOptimized = !1;
      });
      compilation.hooks.optimizeChunksAdvanced.tap(PLUGIN_NAME, chunks => {
        if (!alreadyOptimized) {
          alreadyOptimized = !0;
          return this.customOptionList.reduce((o, customOption) => applyCustomSplitChunk(customOption, compilation, chunks) || o, !1);
        }
      });
    });
  }
};
const verifyCustomOptionList = customOptionList => customOptionList.map(({chunkName, useExistChunk = !1, filterChunk = () => !0, filterModule}, index) => {
  useExistChunk = Boolean(useExistChunk);
  if ("string" != typeof chunkName) throw new Error(`[${PLUGIN_NAME}] invalid chunkName in option #${index}`);
  if ("function" != typeof filterChunk) throw new Error(`[${PLUGIN_NAME}] invalid filterChunk in option #${index}`);
  if ("function" != typeof filterModule) throw new Error(`[${PLUGIN_NAME}] invalid filterModule in option #${index}`);
  return {
    chunkName,
    useExistChunk,
    filterChunk,
    filterModule
  };
});
const applyCustomSplitChunk = ({chunkName, useExistChunk, filterChunk, filterModule}, compilation, chunkList) => {
  const initialChunkNameList = chunkList.map(chunk => chunk.name);
  if (useExistChunk !== initialChunkNameList.includes(chunkName)) throw new Error(useExistChunk ? `[${PLUGIN_NAME}] no chunk exist with chunkName: ${chunkName}` : `[${PLUGIN_NAME}] exist chunk with chunkName: ${chunkName}, set useExistChunk?`);
  const selectedChunkListInclusive = chunkList.filter(chunk => filterChunk({
    chunk,
    chunkList,
    initialChunkNameList
  }));
  const selectedChunkList = useExistChunk ? selectedChunkListInclusive.filter(chunk => chunk.name !== chunkName) : selectedChunkListInclusive;
  if (!selectedChunkList.length) throw new Error(`[${PLUGIN_NAME}] no chunk selected for chunkName: ${chunkName}`);
  const selectedModuleSet = new Set([ ...selectedChunkListInclusive.reduce((o, chunk) => o.concat(chunk.getModules()), []) ]);
  const selectedModuleList = Array.from(selectedModuleSet).filter(module => filterModule({
    module,
    moduleChunkList: module.getChunks().filter(chunk => selectedChunkListInclusive.includes(chunk)),
    selectedChunkList,
    chunkList,
    initialChunkNameList
  }));
  if (!selectedModuleList.length) throw new Error(`[${PLUGIN_NAME}] no module selected for chunkName: ${chunkName}`);
  const targetSplitChunk = useExistChunk ? chunkList.find(chunk => chunk.name === chunkName) : compilation.addChunk(chunkName);
  targetSplitChunk.chunkReason = `${PLUGIN_NAME} (chunkName: ${chunkName}, useExistChunk: ${useExistChunk})`;
  for (const chunk of selectedChunkList) {
    const chunkModule = chunk.getModules();
    const splitModuleList = chunkModule.filter(module => selectedModuleList.includes(module));
    if (splitModuleList.length) {
      if (splitModuleList.length === chunkModule.length) throw new Error(`[${PLUGIN_NAME}] all module from chunk '${chunk.name}' will be split to '${chunkName}'`);
      chunk.split(targetSplitChunk);
      for (const module of splitModuleList) {
        chunk.removeModule(module);
        module.rewriteChunkInReasons(chunk, [ targetSplitChunk ]);
      }
    }
  }
  for (const module of selectedModuleList) connectChunkAndModule(targetSplitChunk, module);
  return !0;
};
const connectChunkAndModule = (chunk, module) => {
  module.addChunk(chunk) && chunk.addModule(module);
};

==> custom-split-chunk-webpack-plugin-0.0.3.tgz: package/library/index.js <==
const PLUGIN_NAME = "CustomSplitChunkWebpackPlugin";
class CustomSplitChunkWebpackPlugin {
  constructor(customOptionList) {
    this.customOptionList = verifyCustomOptionList(customOptionList);
  }
  apply(compiler) {
    compiler.hooks.thisCompilation.tap(PLUGIN_NAME, compilation => {
      let alreadyOptimized = !1;
      compilation.hooks.unseal.tap(PLUGIN_NAME, () => {
        alreadyOptimized = !1;
      });
      compilation.hooks.optimizeChunksAdvanced.tap(PLUGIN_NAME, chunks => {
        if (!alreadyOptimized) {
          alreadyOptimized = !0;
          return this.customOptionList.reduce((o, customOption) => {
            return applyCustomSplitChunk(customOption, compilation, chunks) || o;
          }, !1);
        }
      });
    });
  }
}
exports.CustomSplitChunkWebpackPlugin = CustomSplitChunkWebpackPlugin;
!function(obj, key, value) {
  key in obj ? Object.defineProperty(obj, key, {
    value,
    enumerable: !0,
    configurable: !0,
    writable: !0
  }) : obj[key] = value;
}(CustomSplitChunkWebpackPlugin, "name", PLUGIN_NAME);
const verifyCustomOptionList = customOptionList => customOptionList.map(({chunkName, useExistChunk = !1, filterChunk = chunk => !0, filterModule}, index) => {
  useExistChunk = Boolean(useExistChunk);
  if ("string" != typeof chunkName) throw new Error(`[${PLUGIN_NAME}] invalid chunkName in option #${index}`);
  if ("function" != typeof filterChunk) throw new Error(`[${PLUGIN_NAME}] invalid filterChunk in option #${index}`);
  if ("function" != typeof filterModule) throw new Error(`[${PLUGIN_NAME}] invalid filterModule in option #${index}`);
  return {
    chunkName,
    useExistChunk,
    filterChunk,
    filterModule
  };
});
const applyCustomSplitChunk = ({chunkName, useExistChunk, filterChunk, filterModule}, compilation, chunkList) => {
  const initialChunkNameList = chunkList.map(chunk => chunk.name);
  if (useExistChunk !== initialChunkNameList.includes(chunkName)) throw new Error(useExistChunk ? `[${PLUGIN_NAME}] no chunk exist with chunkName: ${chunkName}` : `[${PLUGIN_NAME}] exist chunk with chunkName: ${chunkName}, set useExistChunk?`);
  const selectedChunkListInclusive = chunkList.filter(chunk => filterChunk({
    chunk,
    chunkList,
    initialChunkNameList
  }));
  const selectedChunkList = useExistChunk ? selectedChunkListInclusive.filter(chunk => chunk.name !== chunkName) : selectedChunkListInclusive;
  if (!selectedChunkList.length) throw new Error(`[${PLUGIN_NAME}] no chunk selected for chunkName: ${chunkName}`);
  const selectedModuleSet = new Set([ ...selectedChunkListInclusive.reduce((o, chunk) => o.concat(chunk.getModules()), []) ]);
  const selectedModuleList = Array.from(selectedModuleSet).filter(module => filterModule({
    module,
    moduleChunkList: module.getChunks().filter(chunk => selectedChunkListInclusive.includes(chunk)),
    selectedChunkList,
    chunkList,
    initialChunkNameList
  }));
  if (!selectedModuleList.length) throw new Error(`[${PLUGIN_NAME}] no module selected for chunkName: ${chunkName}`);
  const targetSplitChunk = useExistChunk ? chunkList.find(chunk => chunk.name === chunkName) : compilation.addChunk(chunkName);
  targetSplitChunk.chunkReason = `${PLUGIN_NAME} (chunkName: ${chunkName}, useExistChunk: ${useExistChunk})`;
  for (const chunk of selectedChunkList) {
    const chunkModule = chunk.getModules();
    const splitModuleList = chunkModule.filter(module => selectedModuleList.includes(module));
    if (splitModuleList.length) {
      if (splitModuleList.length === chunkModule.length) throw new Error(`[${PLUGIN_NAME}] all module from chunk '${chunk.name}' will be split to '${chunkName}'`);
      chunk.split(targetSplitChunk);
      for (const module of splitModuleList) {
        chunk.removeModule(module);
        module.rewriteChunkInReasons(chunk, [ targetSplitChunk ]);
      }
    }
  }
  for (const module of selectedModuleList) connectChunkAndModule(targetSplitChunk, module);
  return !0;
};
const connectChunkAndModule = (chunk, module) => {
  module.addChunk(chunk) && chunk.addModule(module);
};
